@@ -35,20 +35,21 @@ def get_stock_data(stock_symbol, ds, base_url, api_key, stock_fn):
     r = requests.get(end_point)
     time.sleep(15)  # To avoid api limits
     data = json.loads(r.content)
+    data_key = [c for c in data.keys() if c != "Meta Data"][0]
     df = (
-        pd.DataFrame(data['Time Series (Daily)'])
+        pd.DataFrame(data[data_key])
         .T.reset_index()
-        .rename(columns={'index': 'date'})
+        .rename(columns={"index": "date"})
     )
-    df = df[df['date'] == ds]
-    df.columns = ['date', 'open', 'high', 'low', 'close', 'volume']
-    df.drop('volume', axis=1, inplace=True)
+    df = df[df["date"] == ds]
+    df.columns = ["date", "open", "high", "low", "close", "volume"]
+    df.drop("volume", axis=1, inplace=True)
     df.reset_index(drop=True, inplace=True)
     for c in df.columns:
-        if c != 'date':
+        if c != "date":
             df[c] = df[c].astype(float)
-    df['symbol'] = stock_symbol
-    df = df[['symbol', 'date', 'open', 'high', 'low', 'close']]
+    df["symbol"] = stock_symbol
+    df = df[["symbol", "date", "open", "high", "low", "close"]]
     df_json = df.to_json()
     return df_json
 
@@ -72,32 +73,7 @@ def stock_data_to_pd(stocks, jsons_dict):
     dfs = []
     for ticker in stocks:
         stock_df = pd.read_json(jsons_dict[ticker])
-        stock_df = stock_df[['symbol', 'date', 'open', 'high', 'low', 'close']]
+        stock_df = stock_df[["symbol", "date", "open", "high", "low", "close"]]
         dfs.append(stock_df)
     df = pd.concat(dfs, axis=0)
     return df
-
-
-def df_to_plot_format_df(df):
-    """Transforms pandas.DataFrame to plot format.
-
-    Attributes
-    ----------
-        df: pandas DataFrame
-            df with open, high, low and close in different columns
-
-
-    Returns
-    -------
-        df_plot: pandas.DataFrame
-            df with columns type and value.
-    """
-    dfs = []
-    for col in ['open', 'high', 'low', 'close']:
-        aux_df = df[['symbol', 'date', col]]
-        aux_df.columns = ['symbol', 'date', 'value']
-        aux_df['type'] = col
-        dfs.append(aux_df)
-
-    df_plot = pd.concat(dfs)
-    return df_plot
